const webpack = require('webpack')
const merge = require('webpack-merge')
const path = require('path')

function resolve(dir) {
  return path.join(__dirname, '..', dir)
}

var config = {
  output: {
    path: path.resolve(__dirname + '/dist/'),
  },
  module: {
    loaders: [
      {
        test: /\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules/,
      },
      {
        test: /\.vue$/,
        loader: 'vue-loader'
      },
      {
        test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000
        }
      },
      {
        test: /\.less$/,
        loader: 'style-loader!css-loader!less-loader'
      },
      {
        test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000
        }
      }
    ]
  },
  resolve: {
    extensions: ['.js', '.vue', '.json'],
    alias: {
      '@': resolve('src'),
    }
  },
  externals: {
    "element-ui": 'element-ui',
    "vue-router": "vue-router",
    vue: {
      root: 'Vue',
      commonjs: 'vue',
      commonjs2: 'vue',
      amd: 'vue'
    }
  },
  plugins: [
    new webpack.optimize.UglifyJsPlugin({
                                          minimize: true,
                                          sourceMap: false,
                                          mangle: true,
                                          compress: {
                                            warnings: false,
                                            drop_console: true
                                          }
                                        })
  ]
}


module.exports = [
  merge(config, {
    entry: path.resolve(__dirname + '/src/plugin.js'),
    output: {
      filename: 'index.js',
      publicPath: '/dist/',
      library: 'VueComponents',
      libraryTarget: 'umd',
      umdNamedDefine: true
    }
  })
]
